summaryrefslogtreecommitdiffstats
path: root/librss/loader.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
commit47c8a359c5276062c4bc17f0e82410f29081b502 (patch)
tree2d54a5f60a5b74067632f9ef6df58c2bc38155e6 /librss/loader.h
parent6f82532777a35e0e60bbd2b290b2e93e646f349b (diff)
downloadtdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.tar.gz
tdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1157648 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'librss/loader.h')
-rw-r--r--librss/loader.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/librss/loader.h b/librss/loader.h
index 5f0c1447..8c4fcb4d 100644
--- a/librss/loader.h
+++ b/librss/loader.h
@@ -15,7 +15,7 @@
class KURL;
-#include <qobject.h>
+#include <tqobject.h>
namespace KIO
{
@@ -74,7 +74,7 @@ namespace RSS
* wrong and that the data parameter might contain no or invalid
* data.
*/
- void dataRetrieved(const QByteArray &data, bool success);
+ void dataRetrieved(const TQByteArray &data, bool success);
private:
DataRetriever(const DataRetriever &other);
@@ -127,7 +127,7 @@ namespace RSS
void permanentRedirection(const KURL &url);
private slots:
- void slotData(KIO::Job *job, const QByteArray &data);
+ void slotData(KIO::Job *job, const TQByteArray &data);
void slotResult(KIO::Job *job);
void slotPermanentRedirection(KIO::Job *job, const KURL &fromUrl,
const KURL &toUrl);
@@ -194,8 +194,8 @@ namespace RSS
*
* \code
* Loader *loader = Loader::create();
- * connect(loader, SIGNAL(loadingComplete(Loader *, Document, Status)),
- * this, SLOT(slotLoadingComplete(Loader *, Document, Status)));
+ * connect(loader, TQT_SIGNAL(loadingComplete(Loader *, Document, Status)),
+ * this, TQT_SLOT(slotLoadingComplete(Loader *, Document, Status)));
* loader->loadFrom("http://www.blah.org/foobar.rdf", new FileRetriever);
* \endcode
*
@@ -227,7 +227,7 @@ namespace RSS
* if (status != RSS::Success)
* return;
*
- * QString title = doc.title();
+ * TQString title = doc.title();
* // do whatever you want with the information.
* }
* \endcode
@@ -256,10 +256,10 @@ namespace RSS
* Convenience method. Does the same as the above method except that
* it also does the job of connecting the loadingComplete() signal
* to the given slot for you.
* @param object A QObject which features the specified slot
* @param slot Which slot to connect to.
*/
- static Loader *create(QObject *object, const char *slot);
+ static Loader *create(TQObject *object, const char *slot);
/**
* Loads the RSS file referenced by the given URL using the
@@ -305,7 +305,7 @@ namespace RSS
void loadingComplete(Loader *loader, Document doc, Status status);
private slots:
- void slotRetrieverDone(const QByteArray &data, bool success);
+ void slotRetrieverDone(const TQByteArray &data, bool success);
private:
Loader();
@@ -256,10 +256,10 @@ namespace RSS
* it also does the job of connecting the loadingComplete() signal
* to the given slot for you.
- * @param object A QObject which features the specified slot
+ * @param object A TQObject which features the specified slot
* @param slot Which slot to connect to.
*/